@@ -1,6 +1,5 @@
 class Document:
-    def __init__(self, index, width, height, nodes):
-        self.index = str(index).zfill(3)
+    def __init__(self, width, height, nodes):
         self.width = width
         self.height = height
         self.nodes = nodes
