@@ -12,7 +12,7 @@ def make_info(document):
     return connect.df
 
 def predictionsUnique(saved_model_folder,json,labels_tab):
-    predictions_data = getDataForUniquePrediction(json,labels_tab)
+    grapher, predictions_data = getDataForUniquePrediction(json, labels_tab)
 
     torchMode = "cuda" if torch.cuda.is_available() else "cpu"
 
@@ -26,11 +26,7 @@ def predictionsUnique(saved_model_folder,json,labels_tab):
 
     print("Beginning of the prediction", flush=True)
 
-    """
-    OBTENIR LE DOC EN DOC
-    """
-    document = ConvertJsonToDocumentsObjects(json)[0]
-    df = make_info(document)
+    df = grapher.df
 
     assert len(y_pred) == df.shape[0]
 
