@@ -10,7 +10,6 @@ def GetJsonFromFile(jsonPath):
 def ConvertJsonToDocumentsObjects(json):
     listOfDocuments = []
     for i in json:
-        index = i["Index"]
         width = i["Width"]
         height = i["Height"]
         nodes = i["Nodes"]
@@ -18,7 +17,7 @@ def ConvertJsonToDocumentsObjects(json):
         for j in nodes:
             node = Node(XMin=j["XMin"], YMin=j["YMin"], XMax=j["XMax"], YMax=j["YMax"], Object= j["Object"], Tag=j["Tag"])
             listOfNodes.append(node)
-        doc = Document(index=index, width=width, height=height, nodes=listOfNodes)
+        doc = Document(width=width, height=height, nodes=listOfNodes)
         listOfDocuments.append(doc)
     return listOfDocuments
 
